==> mobiusft-1.4.zip: mobiusft-1.4/src/mobius/imagefile/ewf/segment_array.h <==
#ifndef __MOBIUS_IMAGEFILE_EWF_SEGMENT_ARRAY_H__
#define __MOBIUS_IMAGEFILE_EWF_SEGMENT_ARRAY_H__

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/imagefile/segment_array_base.h>

namespace mobius
{
namespace imagefile
{
namespace ewf
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief segment_array subclass
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class segment_array : public segment_array_base
{
public:
  explicit segment_array (const std::string&);
  segment_array (const segment_array&) = default;
  segment_array (segment_array&&) = default;
  segment_array& operator= (const segment_array&) = default;
  segment_array& operator= (segment_array&&) = default;

private:
  virtual const std::string get_next_extension (const std::string&) const override;
};

} // namespace ewf
} // namespace imagefile
} // namespace mobius
#endif

==> mobiusft-1.11.zip: mobiusft-1.11/src/mobius/imagefile/ewf/segment_array.h <==
#ifndef MOBIUS_IMAGEFILE_EWF_SEGMENT_ARRAY_H
#define MOBIUS_IMAGEFILE_EWF_SEGMENT_ARRAY_H

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/imagefile/segment_array_base.h>

namespace mobius
{
namespace imagefile
{
namespace ewf
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief segment_array subclass
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class segment_array : public segment_array_base
{
public:
  explicit segment_array (const std::string&);
  segment_array (const segment_array&) = default;
  segment_array (segment_array&&) = default;
  segment_array& operator= (const segment_array&) = default;
  segment_array& operator= (segment_array&&) = default;

private:
  std::string get_next_extension (const std::string&) const override;
};

} // namespace ewf
} // namespace imagefile
} // namespace mobius
#endif
